@@ -1,7 +1,7 @@
 #' Glmm Sequencing qvalues
 #'
 #' Add qvalue columns to the glmmSeq dataframe
-#' @param glmmResult A glmmSeq object created by 
+#' @param glmmResult A glmmSeq object created by
 #' \code{\link[glmmSeq:glmmSeq]{glmmSeq::glmmSeq()}}.
 #' @param cutoff Prints a table showing the number of probes considered
 #' significant by the pvalue cut-off (default=0.05)
@@ -10,14 +10,14 @@
 #' or set it equal to 1 for the BH procedure (default = NULL).
 #' @param verbose Logical whether to print the number of significant probes
 #' (default=TRUE)
-#' @return Returns a GlmmSeq object with results for gene-wise general linear 
+#' @return Returns a GlmmSeq object with results for gene-wise general linear
 #' mixed models with adjusted p-values using the qvalue function
 #' @importFrom qvalue qvalue
 #' @export
 #' @examples
 #' data(PEAC_minimal_load)
-#' disp <- apply(tpm, 1, function(x) { 
-#' (var(x, na.rm=TRUE)-mean(x, na.rm = TRUE))/(mean(x, na.rm = TRUE)**2) 
+#' disp <- apply(tpm, 1, function(x) {
+#' (var(x, na.rm=TRUE)-mean(x, na.rm = TRUE))/(mean(x, na.rm = TRUE)**2)
 #' })
 #' MS4A1glmm <- glmmSeq(~ Timepoint * EULAR_6m + (1 | PATID),
 #'                      id = "PATID",
@@ -25,15 +25,15 @@
 #'                      metadata = metadata,
 #'                      dispersion = disp[1:5],
 #'                      verbose=FALSE)
-#' MS4A1glmm <- glmmQvals(MS4A1glmm, pi0=1)                    
+#' MS4A1glmm <- glmmQvals(MS4A1glmm, pi0=1)
 
 glmmQvals <- function(glmmResult, cutoff = 0.05, pi0 = NULL, verbose = TRUE) {
-  
-  
-  if (class(glmmResult) != "GlmmSeq") {
+
+
+  if (!inherits(glmmResult, "GlmmSeq")) {
     stop("glmmResult must be a GlmmSeq object")
   }
-  
+
   resultStats <- data.frame(glmmResult@stats, check.names = FALSE)
   for (cn in colnames(resultStats)[grep("P_", colnames(resultStats))]) {
     q_cn <- gsub("P_", "q_", cn)
@@ -48,6 +48,5 @@ glmmQvals <- function(glmmResult, cutoff = 0.05, pi0 = NULL, verbose = TRUE) {
     }
   }
   glmmResult@stats <- as.matrix(resultStats)
-  
   return(glmmResult)
-}
\ No newline at end of file
+}
