@@ -30,8 +30,10 @@ setClass("GlmmSeq", slots = list(
 
 #' Glmm for sequencing results
 #'
-#' @param modelFormula the model formula. For more information of formula
-#' structure see \code{\link[lme4:glmer]{lme4::glmer()}}
+#' @param modelFormula the model formula. This must be of the form `"~ ..."`
+#'   where the structure is assumed to be `"counts ~ ..."`. The formula must
+#'   include a random effects term. For more information on formula structure
+#'   for random effects see \code{\link[lme4:glmer]{lme4::glmer()}}
 #' @param countdata the sequencing count data
 #' @param metadata a data frame of sample information
 #' @param id Column name in metadata which contains the sample IDs to be used
@@ -42,6 +44,7 @@ setClass("GlmmSeq", slots = list(
 #'  \code{\link[lme4:glmer]{lme4::glmer()}}
 #' @param reducedFormula Reduced design formula (default = "")
 #' @param modelData Expanded design matrix
+#' @param designMatrix custom design matrix
 #' @param control the glmer control (default = glmerControl(optimizer = 
 #' "bobyqa")). For more information see
 #' \code{\link[lme4:glmerControl]{lme4::glmerControl()}}.
@@ -93,6 +96,7 @@ glmmSeq <- function(modelFormula,
                     sizeFactors = NULL,
                     reducedFormula = "",
                     modelData = NULL,
+                    designMatrix = NULL,
                     control = glmerControl(optimizer = "bobyqa"),
                     cores = 1,
                     removeDuplicatedMeasures = FALSE,
@@ -181,14 +185,17 @@ glmmSeq <- function(modelFormula,
   if (is.null(modelData)) {
     reducedVars <- rownames(attr(terms(reducedFormula), "factors"))
     varLevels <- lapply(reducedVars, function(x) {
-      if (class(metadata[, x]) == "factor") {
+      if (is.factor(metadata[, x])) {
         return(levels(subsetMetadata[, x]))
       } else {sort(unique(subsetMetadata[, x]))}
     })
     modelData <- expand.grid(varLevels)
     colnames(modelData) <- reducedVars
-  }
-  designMatrix <- model.matrix(reducedFormula, modelData)
+  } 
+
+  if (is.null(designMatrix)){
+    designMatrix <- model.matrix(reducedFormula, modelData)
+  } 
   
   start <- Sys.time()
   fullList <- lapply(rownames(countdata), function(i) {
@@ -319,14 +326,14 @@ glmerApply <- function(geneList,
                        offset,
                        ...) {
   data[, "count"] <- as.numeric(geneList$y)
-  fit <- try(suppressMessages(
+  fit <- try(suppressMessages(suppressWarnings(
     lme4::glmer(fullFormula, data = data, control = control, offset = offset,
                 family = MASS::negative.binomial(theta = 
-                                                   1/geneList$dispersion)),
-    ...),
+                                                   1/geneList$dispersion),
+                ...))),
     silent = TRUE)
   
-  if (class(fit) != "try-error") {
+  if (!inherits(fit, "try-error")) {
     # intercept dropped genes
     if (length(attr(fit@pp$X, "msgRankdrop")) > 0)  {
       return( list(stats = NA, predict = NA, optinfo = NA,
@@ -341,7 +348,7 @@ glmerApply <- function(geneList,
                          c(paste0("Chisq_", rownames(wald)),
                            paste0("P_", rownames(wald))))
     newY <- predict(fit, newdata = modelData, re.form = NA)
-    a <- designMatrix %*% vcov(fit)
+    a <- designMatrix %*% suppressWarnings(vcov(fit))
     b <- as.matrix(a %*% t(designMatrix))
     predVar <- diag(b)
     newSE <- sqrt(predVar)
